pub trait Quantizer {
// Required method
fn quantize(
&mut self,
pixels: &[Argb],
max_colors: usize,
) -> QuantizerResult;
}Expand description
An interface to allow use of different quantization techniques.
pub trait Quantizer {
// Required method
fn quantize(
&mut self,
pixels: &[Argb],
max_colors: usize,
) -> QuantizerResult;
}An interface to allow use of different quantization techniques.